@@ -79,6 +79,29 @@ class BadCommandsCheck(Check):
                     yield DeprecatedEapiCommand(name, line=call, lineno=lineno+1, eapi=pkg.eapi, pkg=pkg)
 
 
+class EendMissingArg(results.LineResult, results.Warning):
+    """Ebuild calls eend with no arguments."""
+
+    @property
+    def desc(self):
+        return f'eend with no arguments, on line {self.lineno}'
+
+
+class EendMissingArgCheck(Check):
+    """Scan an ebuild for calls to eend with no arguments."""
+
+    _source = sources.EbuildParseRepoSource
+    known_results = frozenset([EendMissingArg])
+
+    def feed(self, pkg):
+        for func_node, _ in bash.func_query.captures(pkg.tree.root_node):
+            for node, _ in bash.cmd_query.captures(func_node):
+                line = pkg.node_str(node)
+                if line == "eend":
+                    lineno, _ = node.start_point
+                    yield EendMissingArg(line=line, lineno=lineno+1, pkg=pkg)
+
+
 class MissingSlash(results.VersionResult, results.Error):
     """Ebuild uses a path variable missing a trailing slash."""
 
@@ -417,8 +440,13 @@ class ReferenceInMetadataVar(results.VersionResult, results.Style):
     KEYWORDS must be a simple string with literal content as stated by the QA
     policy guide [#]_.
 
+    LICENSE must specify all license names verbatim, without referring to any
+    variables. The only exception is the LICENSE variable itself, ie appending
+    is allowed [#]_.
+
     .. [#] https://devmanual.gentoo.org/ebuild-writing/variables/#ebuild-defined-variables
     .. [#] https://projects.gentoo.org/qa/policy-guide/ebuild-format.html#pg0105
+    .. [#] https://projects.gentoo.org/qa/policy-guide/ebuild-format.html#pg0106
     """
 
     def __init__(self, variable, refs, **kwargs):
@@ -487,6 +515,17 @@ class MetadataVarCheck(Check):
         if matches:
             yield ReferenceInMetadataVar(var, stable_unique(matches), pkg=pkg)
 
+    @verify_vars('LICENSE')
+    def _raw_text_license(self, var, node, value, pkg):
+        matches = []
+        for var_node, _ in bash.var_query.captures(node):
+            var_str = pkg.node_str(var_node.parent).strip()
+            if var_str in ['$LICENSE', '${LICENSE}']:
+                continue  # LICENSE in LICENSE is ok
+            matches.append(var_str)
+        if matches:
+            yield ReferenceInMetadataVar(var, stable_unique(matches), pkg=pkg)
+
     @verify_vars('SRC_URI')
     def _src_uri(self, var, node, value, pkg):
         if '${HOMEPAGE}' in value:
