@@ -2,6 +2,7 @@
 
 import os
 import re
+import shutil
 import subprocess
 import tarfile
 from collections import defaultdict
@@ -187,6 +188,8 @@ class _RemovalRepo(UnconfiguredTree):
         os.makedirs(pjoin(repo_dir, 'profiles'))
         with open(pjoin(repo_dir, 'profiles', 'repo_name'), 'w') as f:
             f.write('old-repo\n')
+        if os.path.exists(pjoin(repo_dir, 'eclass')):
+            shutil.copytree(pjoin(repo.location, 'eclass'), pjoin(repo_dir, 'eclass'), dirs_exist_ok=True)
         super().__init__(repo_dir)
 
     def __call__(self, pkgs):
