@@ -249,8 +249,8 @@ class TestGitCommitMessageRepoCheck(ReportTestCase):
         # initialize child repo
         self.child_git_repo = make_git_repo()
         self.child_git_repo.run(['git', 'remote', 'add', 'origin', self.parent_git_repo.path])
-        self.child_git_repo.run(['git', 'pull', 'origin', 'master'])
-        self.child_git_repo.run(['git', 'remote', 'set-head', 'origin', 'master'])
+        self.child_git_repo.run(['git', 'pull', 'origin', 'main'])
+        self.child_git_repo.run(['git', 'remote', 'set-head', 'origin', 'main'])
         self.child_repo = make_repo(self.child_git_repo.path)
 
     def init_check(self, options=None, future=0):
@@ -285,14 +285,36 @@ class TestGitCommitMessageRepoCheck(ReportTestCase):
 
         # poorly prefixed commit summary
         self.child_repo.create_ebuild('cat/pkg-4')
-        self.child_git_repo.add_all('version bump', signoff=True)
-        commit = self.child_git_repo.HEAD
+        self.child_git_repo.add_all('version bump to 4', signoff=True)
+        commit1 = self.child_git_repo.HEAD
+        # commit summary missing package version
+        self.child_repo.create_ebuild('cat/pkg-5')
+        self.child_git_repo.add_all('cat/pkg: version bump', signoff=True)
+        commit2 = self.child_git_repo.HEAD
+        # commit summary missing renamed package version
+        self.child_git_repo.move(
+            'cat/pkg/pkg-3.ebuild', 'cat/pkg/pkg-6.ebuild',
+            msg='cat/pkg: version bump and remove old', signoff=True)
+        commit3 = self.child_git_repo.HEAD
+        # revision bumps aren't flagged
+        self.child_repo.create_ebuild('cat/pkg-6-r1')
+        self.child_git_repo.add_all('cat/pkg: revision bump', signoff=True)
         self.init_check()
-        r = self.assertReport(self.check, self.source)
-        expected = git_mod.BadCommitSummary(
+        # allow vVERSION
+        self.child_repo.create_ebuild('cat/pkg-7')
+        self.child_git_repo.add_all('cat/pkg: bump to v7', signoff=True)
+        self.init_check()
+        results = self.assertReports(self.check, self.source)
+        r1 = git_mod.BadCommitSummary(
             "summary missing 'cat/pkg' package prefix",
-            'version bump', commit=commit)
-        assert r == expected
+            'version bump to 4', commit=commit1)
+        r2 = git_mod.BadCommitSummary(
+            "summary missing package version '5'",
+            'cat/pkg: version bump', commit=commit2)
+        r3 = git_mod.BadCommitSummary(
+            "summary missing package version '6'",
+            'cat/pkg: version bump and remove old', commit=commit3)
+        assert set(results) == {r1, r2, r3}
 
     def test_bad_commit_summary_category(self):
         # properly prefixed commit summary
@@ -343,8 +365,8 @@ class TestGitPkgCommitsCheck(ReportTestCase):
         # initialize child repo
         self.child_git_repo = make_git_repo()
         self.child_git_repo.run(['git', 'remote', 'add', 'origin', self.parent_git_repo.path])
-        self.child_git_repo.run(['git', 'pull', 'origin', 'master'])
-        self.child_git_repo.run(['git', 'remote', 'set-head', 'origin', 'master'])
+        self.child_git_repo.run(['git', 'pull', 'origin', 'main'])
+        self.child_git_repo.run(['git', 'remote', 'set-head', 'origin', 'main'])
         self.child_repo = make_repo(self.child_git_repo.path)
 
     def init_check(self, options=None, future=0):
@@ -417,7 +439,7 @@ class TestGitPkgCommitsCheck(ReportTestCase):
         self.parent_repo.create_ebuild('cat/pkg-1', keywords=['amd64'])
         self.parent_git_repo.add_all('cat/pkg: version bump to 1')
         # pull changes and remove it from the child repo
-        self.child_git_repo.run(['git', 'pull', 'origin', 'master'])
+        self.child_git_repo.run(['git', 'pull', 'origin', 'main'])
         self.child_git_repo.remove('cat/pkg/pkg-1.ebuild', msg='cat/pkg: remove 1')
         commit = self.child_git_repo.HEAD
         self.init_check()
@@ -436,7 +458,7 @@ class TestGitPkgCommitsCheck(ReportTestCase):
         self.parent_repo.create_ebuild('cat/pkg-1', keywords=['~amd64'])
         self.parent_git_repo.add_all('cat/pkg: version bump to 1')
         # pull changes and remove it from the child repo
-        self.child_git_repo.run(['git', 'pull', 'origin', 'master'])
+        self.child_git_repo.run(['git', 'pull', 'origin', 'main'])
         self.child_git_repo.remove('cat/pkg/pkg-1.ebuild', msg='cat/pkg: remove 1')
         commit = self.child_git_repo.HEAD
         self.init_check()
@@ -455,7 +477,7 @@ class TestGitPkgCommitsCheck(ReportTestCase):
         self.parent_repo.create_ebuild('newcat/newpkg-2', rdepend="cat/dep1 cat/dep2")
         self.parent_git_repo.add_all('newcat/newpkg: version bump')
         # pull changes to child repo
-        self.child_git_repo.run(['git', 'pull', 'origin', 'master'])
+        self.child_git_repo.run(['git', 'pull', 'origin', 'main'])
         # change pkg RDEPEND and commit
         with open(pjoin(self.child_git_repo.path, 'cat/pkg/pkg-0.ebuild'), 'a') as f:
             f.write('RDEPEND="cat/dep1"\n')
@@ -480,7 +502,7 @@ class TestGitPkgCommitsCheck(ReportTestCase):
         self.parent_repo.create_ebuild('cat/pkg-1', keywords=['~amd64'])
         self.parent_git_repo.add_all('cat/pkg: version bump to 1')
         # pull changes and modify its slot in the child repo
-        self.child_git_repo.run(['git', 'pull', 'origin', 'master'])
+        self.child_git_repo.run(['git', 'pull', 'origin', 'main'])
         self.child_repo.create_ebuild('cat/pkg-1', keywords=['~amd64'], slot='1')
         self.child_git_repo.add_all('cat/pkg: update SLOT to 1')
         self.init_check()
@@ -554,8 +576,8 @@ class TestGitEclassCommitsCheck(ReportTestCase):
         # initialize child repo
         self.child_git_repo = make_git_repo()
         self.child_git_repo.run(['git', 'remote', 'add', 'origin', self.parent_git_repo.path])
-        self.child_git_repo.run(['git', 'pull', 'origin', 'master'])
-        self.child_git_repo.run(['git', 'remote', 'set-head', 'origin', 'master'])
+        self.child_git_repo.run(['git', 'pull', 'origin', 'main'])
+        self.child_git_repo.run(['git', 'remote', 'set-head', 'origin', 'main'])
         self.child_repo = make_repo(self.child_git_repo.path)
 
     def init_check(self, options=None, future=0):
